@@ -3,15 +3,15 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
 import datetime
 
-from typing import Optional, List, Any, TYPE_CHECKING
+from typing import Optional, List, Any, TYPE_CHECKING, Union
 
-from qt import Qt, QModelIndex
+from qt import Qt, QModelIndex, QPersistentModelIndex
 from qt import QAbstractTableModel, QDialogButtonBox, QDialog
 from qt import QHBoxLayout, QVBoxLayout, QCheckBox
 from qt import QItemSelectionModel, QAbstractItemView
@@ -34,14 +34,14 @@ class GamesModel(QAbstractTableModel):
     """data for the list of games"""
 
     def __init__(self) ->None:
-        QAbstractTableModel.__init__(self)
+        super().__init__()
         self._resultRows:List[List[Any]] = []
 
-    def columnCount(self, unusedParent:QModelIndex=QModelIndex()) ->int:
+    def columnCount(self, unusedParent:Union[QModelIndex,QPersistentModelIndex]=QModelIndex()) ->int:
         """including the hidden col 0"""
         return 3
 
-    def rowCount(self, parent:QModelIndex=QModelIndex()) ->int:
+    def rowCount(self, parent:Union[QModelIndex,QPersistentModelIndex]=QModelIndex()) ->int:
         """how many games"""
         if parent.isValid():
             # we have only top level items
@@ -56,7 +56,7 @@ class GamesModel(QAbstractTableModel):
         finally:
             self.endResetModel()
 
-    def index(self, row:int, column:int, parent:QModelIndex=QModelIndex()) ->QModelIndex:
+    def index(self, row:int, column:int, parent:Union[QModelIndex,QPersistentModelIndex]=QModelIndex()) ->QModelIndex:
         """helper"""
         if (row < 0
                 or column < 0
@@ -66,8 +66,9 @@ class GamesModel(QAbstractTableModel):
             return QModelIndex()
         return self.createIndex(row, column, 0)
 
-    def data(self, index:QModelIndex, role:int=Qt.ItemDataRole.DisplayRole) ->Any:
+    def data(self, index:Union[QModelIndex,QPersistentModelIndex], role:int=Qt.ItemDataRole.DisplayRole) ->Any:
         """get score table from view"""
+        assert isinstance(index, QModelIndex)
         if role is None:
             role = Qt.ItemDataRole.DisplayRole
         if not (index.isValid() and role == Qt.ItemDataRole.DisplayRole):
@@ -86,7 +87,7 @@ class GamesModel(QAbstractTableModel):
                 return dateVal.strftime('%c')
             if index.column() == 0:
                 return int(unformatted)
-        return QAbstractTableModel.data(self, index, role)
+        return super().data(index, role)
 
     def headerData(self, section:int, orientation:Qt.Orientation, role:int=Qt.ItemDataRole.DisplayRole) ->Optional[str]:
         """for the two visible columns"""
@@ -121,14 +122,17 @@ class Games(QDialog):
         self.buttonBox.setStandardButtons(QDialogButtonBox.StandardButton.Cancel)
         self.newButton = self.buttonBox.addButton(
             i18nc('start a new game', "&New"), QDialogButtonBox.ButtonRole.ActionRole)
+        assert self.newButton
         self.newButton.setIcon(KIcon("document-new"))
         self.newButton.clicked.connect(self.accept)
         self.loadButton = self.buttonBox.addButton(
             i18n("&Load"), QDialogButtonBox.ButtonRole.AcceptRole)
+        assert self.loadButton
         self.loadButton.clicked.connect(self.loadGame)
         self.loadButton.setIcon(KIcon("document-open"))
         self.deleteButton = self.buttonBox.addButton(
             i18n("&Delete"), QDialogButtonBox.ButtonRole.ActionRole)
+        assert self.deleteButton
         self.deleteButton.setIcon(KIcon("edit-delete"))
         self.deleteButton.clicked.connect(self.delete)
 
@@ -150,27 +154,30 @@ class Games(QDialog):
         self.view.doubleClicked.connect(self.loadGame)
         chkPending.stateChanged.connect(self.pendingOrNot)
 
-    def showEvent(self, unusedEvent:'QEvent') ->None:
+    def showEvent(self, unusedEvent:Optional['QEvent']) ->None:
         """only now get the data set. Not doing this in__init__ would eventually
         make it easier to subclass from some generic TableEditor class"""
         self.setQuery()
         self.view.initView()
         self.selectionChanged()
 
-    def keyPressEvent(self, event:'QKeyEvent') ->None:
+    def keyPressEvent(self, event:Optional['QKeyEvent']) ->None:
         """use insert/delete keys for insert/delete"""
-        key = event.key()
-        if key == Qt.Key.Key_Delete:
-            self.delete()
-            event.ignore()
-            return
-        QDialog.keyPressEvent(self, event)
+        if event:
+            key = event.key()
+            if key == Qt.Key.Key_Delete:
+                self.delete()
+                event.ignore()
+                return
+            super().keyPressEvent(event)
 
     def selectionChanged(self) ->None:
         """update button states according to selection"""
         selectedRows = len(self.selection.selectedRows())
-        self.loadButton.setEnabled(selectedRows == 1)
-        self.deleteButton.setEnabled(selectedRows >= 1)
+        if button := self.loadButton:
+            button.setEnabled(selectedRows == 1)
+        if button := self.deleteButton:
+            button.setEnabled(selectedRows >= 1)
 
     def setQuery(self) ->None:
         """define the query depending on self.OnlyPending"""
@@ -228,9 +235,12 @@ class Games(QDialog):
                     Query("DELETE FROM score WHERE game = ?", (game, ))
                     Query("DELETE FROM game WHERE id = ?", (game, ))
                 self.setQuery()  # just reload entire table
-        allGames = self.view.selectionModel().selectedRows(0)
-        deleteGames = [x.data() for x in allGames]
-        if not deleteGames:
+        if model := self.view.selectionModel():
+            allGames = model.selectedRows(0)
+            deleteGames = [x.data() for x in allGames]
+            if not deleteGames:
+                return
+        else:
             return
         WarningYesNo(
             i18n(
