@@ -3,7 +3,7 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -24,7 +24,7 @@ try:
     from qt import Qt, QEvent, QMetaObject, QTimer
     from qt import QWidget, QGridLayout, QAction
 except ImportError as importError:
-    NOTFOUND.append(f'Please install PyQt5: {importError}')
+    NOTFOUND.append(f'Please install PyQt6 or Pyside6: {importError}')
 
 try:
     from twisted.spread import pb # pylint: disable=unused-import
@@ -63,7 +63,7 @@ if NOTFOUND:
 if TYPE_CHECKING:
     from deferredutil import Request
     from twisted.internet.defer import Deferred
-    from qt import QSize, QKeySequence
+    from qt import QSize
     from scene import GameScene
 
 def cleanExit(*unusedArgs:Any) ->None:
@@ -102,6 +102,7 @@ class MainWindow(KXmlGuiWindow):
         self.playerWindow:Optional[PlayerList] = None
         self.rulesetWindow:Optional[RulesetSelector] = None
         self.confDialog:Optional[ConfigDialog] = None
+        self.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         self.__installReactor()
         if Options.gui:
             KStandardAction.preferences(
@@ -173,7 +174,7 @@ class MainWindow(KXmlGuiWindow):
 
     def sizeHint(self) ->'QSize':
         """give the main window a sensible default size"""
-        result = KXmlGuiWindow.sizeHint(self)
+        result = super().sizeHint()
         result.setWidth(result.height() * 3 // 2)
                         # we want space to the right for the buttons
         # the default is too small. Use at least 2/3 of screen height and 1/2
@@ -185,7 +186,7 @@ class MainWindow(KXmlGuiWindow):
         result.setWidth(width)
         return result
 
-    def _kajonggToggleAction(self, name:str, icon:str, shortcut:Optional['Qt.Key']=None,
+    def _kajonggToggleAction(self, name:str, icon:str, shortcut:Optional[str]=None,
         actionData:Optional[Union[str, Type['QWidget']]]=None) ->Action:
         """a checkable action"""
         res = Action(self,
@@ -224,26 +225,26 @@ class MainWindow(KXmlGuiWindow):
             "scoreGame",
             "draw-freehand",
             self.startScoringGame,
-            Qt.Key.Key_C)
+            "Ctrl+C")
         self.actionPlayGame = Action(
             self,
             "play",
             "arrow-right",
             self.playGame,
-            Qt.Key.Key_N)
+            "Ctrl+N")
         self.actionAbortGame = Action(
             self,
             "abort",
             "dialog-close",
             self.abortAction,
-            Qt.Key.Key_W)
+            "Ctrl+W")
         self.actionAbortGame.setEnabled(False)
         self.actionQuit = Action(
             self,
             "quit",
             "application-exit",
             self.close,
-            Qt.Key.Key_Q)
+            "Ctrl+Q")
         self.actionPlayers = Action(
             self,
             "players", "im-user", self.slotPlayers)
@@ -253,33 +254,33 @@ class MainWindow(KXmlGuiWindow):
             "games-kajongg-law",
             self.slotRulesets)
         self.actionChat = self._kajonggToggleAction("chat", "call-start",
-                                                    shortcut=Qt.Key.Key_H, actionData=ChatWindow)
+                                                    shortcut="Ctrl+H", actionData=ChatWindow)
         self.actionChat.setEnabled(False)
         self.actionAngle = Action(
             self,
             "angle",
             "object-rotate-left",
             self.changeAngle,
-            Qt.Key.Key_G)
+            "Ctrl+G")
         self.actionAngle.setEnabled(False)
         self.actionScoreTable = self._kajonggToggleAction(
             "scoreTable", "format-list-ordered",
-            Qt.Key.Key_T, actionData=ScoreTable)
+            "Ctrl+T", actionData=ScoreTable)
         self.actionScoreTable.setEnabled(False)
         self.actionExplain = self._kajonggToggleAction(
             "explain", "applications-education",
-            Qt.Key.Key_E, actionData=ExplainView)
+            "Ctrl+E", actionData=ExplainView)
         self.actionExplain.setEnabled(False)
         self.actionFullscreen = self._kajonggToggleAction(
             "fullscreen", "view-fullscreen",
-            shortcut=cast(Qt.Key, Qt.Key.Key_F | Qt.KeyboardModifier.ShiftModifier))  # type:ignore[operator]
+            shortcut="Ctrl+Shift+F")
         self.actionFullscreen.toggled.connect(self.fullScreen)
         self.actionAutoPlay = Action(
             self,
             "demoMode",
             "arrow-right-double",
             None,
-            Qt.Key.Key_D)
+            "Ctrl+D")
         self.actionAutoPlay.setCheckable(True)
         self.actionAutoPlay.setEnabled(True)
         self.actionAutoPlay.toggled.connect(self._toggleDemoMode)
@@ -323,13 +324,14 @@ class MainWindow(KXmlGuiWindow):
     def close(self, unusedResult:Any=None) ->bool:
         """wrap close() because we call it with a QTimer"""
         if isAlive(self):
-            return KXmlGuiWindow.close(self)
+            return super().close()
         return True  # is closed
 
-    def closeEvent(self, event:QEvent) ->None:
-        KXmlGuiWindow.closeEvent(self, event)
-        if event.isAccepted() and self.exitReady:
-            QTimer.singleShot(5000, self.aboutToQuit)
+    def closeEvent(self, event:Optional[QEvent]) ->None:
+        super().closeEvent(event)
+        if event:
+            if event.isAccepted() and self.exitReady:
+                QTimer.singleShot(5000, self.aboutToQuit)
 
     def queryClose(self) ->bool:
         """queryClose, queryExit and aboutToQuit are no
@@ -453,7 +455,8 @@ class MainWindow(KXmlGuiWindow):
         else:
             if Debug.quit:
                 logDebug('aboutToQuit: mainWindow is already None')
-            # this does not happen with PyQt5/6 or PySide2, only with PySide6
+            # this does not happen with PyQt6, only with PySide6
+            # last test was with Pyside6.7.2
             # return here to avoid recursion in StateSaver
             return
         StateSaver.saveAll()
@@ -545,11 +548,13 @@ class MainWindow(KXmlGuiWindow):
             i18nc('kajongg @info:tooltip',
                   'Chat with the other players.'))
 
-    def changeEvent(self, event:QEvent) ->None:
+    def changeEvent(self, event:Optional[QEvent]) ->None:
         """when the applicationwide language changes, recreate GUI"""
-        if event.type() == QEvent.Type.LanguageChange:
-            self.setupGUI()
-            self.retranslateUi()
+        if event:
+            super().changeEvent(event)
+            if event.type() == QEvent.Type.LanguageChange:
+                self.setupGUI()
+                self.retranslateUi()
 
     def slotPlayers(self) ->None:
         """show the player list"""
